.. py:function:: sf_laguerre_3(a, x [, ret])

    Wrapper for :c:func:`gsl_sf_laguerre_3`
    c code signature: double gsl_sf_laguerre_3( double a,  double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rd__O`
    
    :param double a: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_laguerre_3_e(a, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_laguerre_3_e`
    c code signature: int gsl_sf_laguerre_3_e(const double a, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord`
    
    :param double a: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_laguerre_2(a, x [, ret])

    Wrapper for :c:func:`gsl_sf_laguerre_2`
    c code signature: double gsl_sf_laguerre_2( double a,  double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rd__O`
    
    :param double a: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_laguerre_n(n, a, x [, ret])

    Wrapper for :c:func:`gsl_sf_laguerre_n`
    c code signature: double gsl_sf_laguerre_n( int n,  double a,  double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d_d__Rd__O`
    
    :param int n: positional argument 0
    :param double a: positional argument 1
    :param double x: positional argument 2
    :param double ret: positional argument 3
    :rtype:  double 
    :return: result 

.. py:function:: sf_laguerre_1_e(a, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_laguerre_1_e`
    c code signature: int gsl_sf_laguerre_1_e(const double a, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord`
    
    :param double a: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_laguerre_1(a, x [, ret])

    Wrapper for :c:func:`gsl_sf_laguerre_1`
    c code signature: double gsl_sf_laguerre_1( double a,  double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rd__O`
    
    :param double a: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_laguerre_2_e(a, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_laguerre_2_e`
    c code signature: int gsl_sf_laguerre_2_e(const double a, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord`
    
    :param double a: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_laguerre_n_e(n, a, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_laguerre_n_e`
    c code signature: int gsl_sf_laguerre_n_e(const int n, const double a, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d_d__Rl__Ord`
    
    :param int n: positional argument 0
    :param double a: positional argument 1
    :param double x: positional argument 2
    :param int ret: positional argument 3
    :param double result.val: positional argument 4
    :param double result.err: positional argument 5
    :rtype:  tuple(:param int ret: positional argument 3, :param double result.val: positional argument 4, :param double result.err: positional argument 5) 
    :return: result 

